/**
 * @file
 * VuoList_VuoCurveEasing C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoCurveEasing_H
#define VuoList_VuoCurveEasing_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoCurveEasing VuoList_VuoCurveEasing
 * A list of @ref VuoCurveEasing elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoCurveEasing
 * A list of @ref VuoCurveEasing elements.
 */
#ifndef VuoList_VuoCurveEasing_TYPE_DEFINED
typedef void * VuoList_VuoCurveEasing;
#endif

/**
 * Creates a new list of @ref VuoCurveEasing elements.
 */
VuoList_VuoCurveEasing VuoListCreate_VuoCurveEasing(void);

/**
 * Returns the @ref VuoCurveEasing at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoCurveEasing VuoListGetValueAtIndex_VuoCurveEasing(const VuoList_VuoCurveEasing list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoCurveEasing(VuoList_VuoCurveEasing list, const VuoCurveEasing value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoCurveEasing(VuoList_VuoCurveEasing list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoCurveEasing(VuoList_VuoCurveEasing list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoCurveEasing(const VuoList_VuoCurveEasing list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoCurveEasing VuoList_VuoCurveEasing_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoCurveEasing_jsonFromValue(const VuoList_VuoCurveEasing value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoCurveEasing_summaryFromValue(const VuoList_VuoCurveEasing value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoCurveEasing VuoList_VuoCurveEasing_valueFromString(const char *str);
char * VuoList_VuoCurveEasing_stringFromValue(const VuoList_VuoCurveEasing value);
/// @}

/**
 * @}
 */

#endif
