/**
 * @file
 * VuoList_VuoKey C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoKey_H
#define VuoList_VuoKey_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoKey VuoList_VuoKey
 * A list of @ref VuoKey elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoKey
 * A list of @ref VuoKey elements.
 */
#ifndef VuoList_VuoKey_TYPE_DEFINED
typedef void * VuoList_VuoKey;
#endif

/**
 * Creates a new list of @ref VuoKey elements.
 */
VuoList_VuoKey VuoListCreate_VuoKey(void);

/**
 * Returns the @ref VuoKey at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoKey VuoListGetValueAtIndex_VuoKey(const VuoList_VuoKey list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoKey(VuoList_VuoKey list, const VuoKey value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoKey(VuoList_VuoKey list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoKey(VuoList_VuoKey list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoKey(const VuoList_VuoKey list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoKey VuoList_VuoKey_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoKey_jsonFromValue(const VuoList_VuoKey value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoKey_summaryFromValue(const VuoList_VuoKey value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoKey VuoList_VuoKey_valueFromString(const char *str);
char * VuoList_VuoKey_stringFromValue(const VuoList_VuoKey value);
/// @}

/**
 * @}
 */

#endif
